/* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-

   icon.h for the Openbox window manager
   Copyright (c) 2003-2007   Dana Jansens

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   See the COPYING file for a copy of the GNU General Public License.
*/

/* GIMP RGBA C-Source image dump (icon.h) */

#define OB_DEFAULT_ICON_WIDTH (48)
#define OB_DEFAULT_ICON_HEIGHT (48)
#define OB_DEFAULT_ICON_BYTES_PER_PIXEL (4) /* 3:RGB, 4:RGBA */
#define OB_DEFAULT_ICON_COMMENT \
  "To recreate this file, save an image as \"C-Source\" in The Gimp. Use \"ob_default_icon\" as the Prefixed Name. Enable Glib Types. Enable Save Alpha Channel. Enable Use Macros instead of Struct."
#define OB_DEFAULT_ICON_PIXEL_DATA ((guint8*) OB_DEFAULT_ICON_pixel_data)
static const guint8 OB_DEFAULT_ICON_pixel_data[48 * 48 * 4 + 1] =
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\10"
 "\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373"
 "\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10"
 "\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10"
 "\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10"
 "\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373"
 "\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10"
 "\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10"
 "\10\373\10\10\10\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10"
 "\373\10\10\10\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22"
 "\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20"
 "\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373"
 "\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24"
 "\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22"
 "\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20"
 "\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373\20\22\24\373"
 "\20\22\24\373\23\26\32\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\20\22\24\373\277\324\347\373\277\325\347\373\277\324\347\373\277"
 "\324\347\373\277\324\347\373\277\324\347\373\277\324\347\373\277\324\347\373"
 "\277\324\347\373\277\324\347\373\277\324\347\373\277\324\347\373\277\324\347"
 "\373\277\325\347\373\277\324\347\373\300\324\347\373\277\324\347\373\277\324"
 "\347\373\277\324\347\373\277\324\347\373\300\324\347\373\277\324\347\373\277"
 "\324\347\373\277\324\347\373\277\324\347\373\277\324\347\373\277\324\347\373"
 "\277\324\347\373\277\324\347\373\277\324\347\373\277\324\347\373\300\324\347"
 "\373\277\324\347\373\277\324\347\373\277\324\347\373\277\324\347\373\277\325"
 "\347\373\277\324\347\373\277\324\347\373\277\324\347\373\20\22\24\373\10\10"
 "\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\20\22\24\373\277\323"
 "\347\373l\232\277\373n\232\277\373n\232\300\373n\232\300\373o\233\300\373"
 "o\233\300\373o\233\301\373o\235\301\373q\235\303\373q\235\303\373q\235\303"
 "\373r\236\304\373r\236\304\373t\236\304\373t\237\304\373t\237\305\373t\237"
 "\305\373u\237\305\373u\237\306\373u\241\306\373u\241\306\373w\241\307\373"
 "w\242\307\373y\242\307\373y\242\307\373y\242\310\373y\245\310\373z\245\311"
 "\373z\244\311\373z\245\311\373|\245\311\373|\245\313\373|\245\313\373}\247"
 "\313\373}\247\314\373}\247\314\373}\250\314\373\177\251\315\373t\232\277\373"
 "\20\22\24\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\20"
 "\22\24\373\277\323\346\373l\232\276\373l\230\277\373l\230\277\373n\232\277"
 "\373n\232\300\373n\233\300\373o\233\300\373o\233\301\373o\233\301\373o\233"
 "\301\373q\235\301\373q\235\303\373q\236\303\373r\236\303\373r\236\304\373"
 "r\237\304\373t\236\304\373t\237\305\373t\237\305\373t\241\305\373u\241\306"
 "\373u\241\306\373u\242\306\373w\241\306\373w\241\307\373w\242\307\373y\244"
 "\307\373y\244\310\373y\244\310\373y\245\310\373z\245\311\373z\244\311\373"
 "z\245\311\373|\247\313\373|\247\313\373|\245\313\373}\250\313\373}\250\314"
 "\373q\230\276\373\20\22\24\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\10\10\10\373\20\22\24\373\275\322\345\373l\227\276\373k\230\276\373l\230"
 "\276\373l\232\277\373l\230\277\373n\232\277\373n\233\300\373n\232\300\373"
 "n\232\300\373o\233\300\373o\233\301\373o\233\301\373q\233\301\373q\235\303"
 "\373q\235\303\373r\235\303\373r\236\304\373r\237\304\373r\237\304\373t\236"
 "\304\373t\237\305\373t\237\305\373u\237\305\373u\241\306\373u\241\306\373"
 "u\241\306\373w\242\307\373y\241\307\373w\244\307\373y\242\307\373y\244\310"
 "\373z\244\310\373y\244\310\373z\244\311\373z\245\311\373z\245\311\373|\245"
 "\313\373|\245\313\373o\230\275\373\20\22\24\373\10\10\10\373\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\10\10\10\373\17\22\24\373\273\322\344\373k\227\275\373"
 "k\227\275\373k\230\276\373k\227\276\373l\230\276\373l\232\277\373l\232\277"
 "\373n\232\277\373n\232\277\373n\232\300\373n\233\300\373o\232\300\373o\233"
 "\301\373o\233\301\373o\233\301\373q\235\303\373r\236\303\373q\235\303\373"
 "r\235\303\373r\236\304\373r\237\304\373r\237\304\373u\237\305\373t\237\305"
 "\373t\241\305\373u\237\306\373u\237\306\373w\241\306\373w\241\306\373w\242"
 "\307\373w\242\307\373w\242\307\373z\242\310\373y\244\310\373z\244\310\373"
 "y\244\310\373|\244\311\373z\245\311\373n\225\273\373\17\22\24\373\10\10\10"
 "\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\17\22\24\373\273\321\344"
 "\373k\227\275\373i\227\275\373k\227\275\373k\230\276\373k\227\276\373l\230"
 "\276\373l\230\276\373l\232\277\373l\232\277\373l\230\277\373n\232\277\373"
 "n\232\300\373n\233\300\373o\233\300\373o\233\301\373o\235\301\373o\235\301"
 "\373q\235\301\373r\235\303\373q\236\303\373r\235\303\373r\236\304\373r\236"
 "\304\373r\236\304\373t\237\304\373t\236\305\373t\237\305\373t\237\305\373"
 "w\241\306\373u\241\306\373u\241\306\373w\242\306\373w\242\307\373w\242\307"
 "\373w\244\307\373y\244\310\373y\244\310\373z\244\310\373l\225\272\373\17\22"
 "\24\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\17\22\24"
 "\373\272\321\343\373i\225\273\373i\225\273\373i\227\275\373k\225\275\373i"
 "\227\275\373k\227\275\373k\230\276\373l\230\276\373l\230\276\373l\230\276"
 "\373n\232\277\373l\230\277\373n\232\277\373n\232\300\373o\233\300\373o\233"
 "\300\373o\233\300\373o\233\301\373o\235\301\373o\233\301\373q\235\303\373"
 "r\235\303\373q\236\303\373r\236\303\373t\236\304\373r\236\304\373r\237\304"
 "\373t\237\304\373u\237\305\373t\237\305\373t\241\305\373u\241\306\373u\241"
 "\306\373w\241\306\373u\242\306\373w\242\307\373w\242\307\373w\242\307\373"
 "k\224\271\373\17\22\24\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\17\22\24\373\271\320\343\373h\224\272\373_\212\260\373_\212\260"
 "\373`\212\261\373`\212\261\373`\212\261\373`\212\261\373`\212\261\373`\214"
 "\261\373b\214\263\373b\214\263\373b\214\263\373b\214\263\373b\214\263\373"
 "c\214\263\373c\216\264\373e\216\264\373e\216\264\373c\216\264\373e\216\264"
 "\373e\216\264\373f\217\265\373f\217\265\373e\217\265\373f\217\265\373f\217"
 "\265\373f\217\265\373f\221\265\373f\217\266\373f\221\266\373h\221\266\373"
 "i\221\266\373h\221\266\373h\222\266\373h\222\270\373i\221\270\373i\222\270"
 "\373i\222\270\373i\222\270\373\17\22\24\373\10\10\10\373\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\10\10\10\373\17\21\24\373T\201\250\373T\201\250\373T\201\250"
 "\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201"
 "\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373"
 "T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250"
 "\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201"
 "\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373"
 "T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250\373T\201\250"
 "\373T\201\250\373T\201\250\373T\201\250\373\17\21\24\373\10\10\10\373\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\17\21\24\373T\201\250\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373T\201"
 "\250\373\17\21\24\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10"
 "\373\17\21\24\373T\201\250\373\375\376\376\373\375\376\376\373\375\376\376"
 "\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375"
 "\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373"
 "\375\376\376\373\375\376\376\373\375\375\376\373\375\375\376\373\375\375\376"
 "\373\375\376\376\373\375\375\376\373\375\375\376\373\375\376\376\373\375\375"
 "\376\373\375\375\376\373\375\376\376\373\375\375\376\373\375\375\376\373\375"
 "\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373"
 "\375\375\376\373\375\375\376\373T\201\250\373\17\21\24\373\10\10\10\373\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\17\21\24\373T\201\250\373\373"
 "\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373"
 "\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376"
 "\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375"
 "\376\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373\373"
 "\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373"
 "\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376"
 "\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375"
 "\376\373\373\375\376\373\373\375\376\373\373\375\376\373\373\375\376\373T"
 "\201\250\373\17\21\24\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\17\21\24\373T\201\250\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375"
 "\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373"
 "\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376"
 "\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375"
 "\376\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373"
 "\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373T\201\250\373\17\21\24\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\17\21\23\373T\201\250\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373T"
 "\201\250\373\17\21\23\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\17\21\23\373T\201\250\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375"
 "\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373"
 "\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376"
 "\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\375\376\373\375"
 "\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373"
 "\375\375\376\373\375\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373T\201\250\373\17\21\23\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\17\21\23\373T\201\250\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373T"
 "\201\250\373\17\21\23\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\17\21\23\373T\201\250\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375"
 "\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373"
 "\375\376\376\373\375\376\376\373\375\375\376\373\375\375\376\373\375\376\376"
 "\373\375\375\376\373\375\376\376\373\375\375\376\373\375\376\376\373\375\375"
 "\376\373\375\376\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375"
 "\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373T\201\250\373\17\21\23\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\17\20\23\373T\201\250\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373T"
 "\201\250\373\17\20\23\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\17\20\23\373T\201\250\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375"
 "\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\375\376\373"
 "\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376"
 "\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375"
 "\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375"
 "\375\376\373\375\375\376\373\375\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373T\201\250\373\17\20\23\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\17\20\23\373T\201\250\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373T"
 "\201\250\373\17\20\23\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\16\20\23\373T\201\250\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375"
 "\376\376\373\375\376\376\373\375\375\376\373\375\375\376\373\375\375\376\373"
 "\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376"
 "\373\375\375\376\373\375\375\376\373\375\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\375\375\376\373\374\375\376\373\375\375\376\373\375"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373T\201\250\373\17\20\23\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\16\20\22\373T\201\250\373\373"
 "\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373"
 "\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375"
 "\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375"
 "\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373"
 "\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373"
 "\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375"
 "\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375"
 "\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373T"
 "\201\250\373\16\20\22\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\16\20\22\373T\201\250\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375\376\376\373\375"
 "\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373"
 "\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373T\201\250\373\16\20\22\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\16\20\22\373T\201\250\373\373"
 "\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373"
 "\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375"
 "\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375"
 "\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373"
 "\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373"
 "\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375"
 "\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375"
 "\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373T"
 "\201\250\373\16\20\22\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\16\20\22\373T\201\250\373\375\376\376\373\375\376\376\373\375\376"
 "\376\373\375\376\376\373\375\376\376\373\375\375\376\373\375\375\376\373\375"
 "\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373"
 "\375\375\376\373\375\375\376\373\375\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373T\201\250\373\16\20\22\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\16\20\22\373T\201\250\373\373"
 "\375\375\373\373\374\375\373\373\374\375\373\373\375\375\373\373\375\375\373"
 "\373\374\375\373\373\375\375\373\373\374\375\373\373\374\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374"
 "\375\373\373\375\375\373\373\374\375\373\373\375\375\373\373\374\375\373\373"
 "\375\375\373\373\374\375\373\373\374\375\373\373\375\375\373\373\375\375\373"
 "\373\374\375\373\373\374\375\373\373\375\375\373\373\375\375\373\373\374\375"
 "\373\373\374\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375"
 "\375\373\373\375\375\373\373\375\375\373\373\374\375\373\373\374\375\373T"
 "\201\250\373\16\20\22\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\16\20\22\373T\201\250\373\375\375\376\373\375\375\376\373\375\375"
 "\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375"
 "\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373"
 "\375\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373T\201\250\373\16\20\22\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\16\20\22\373T\201\250\373\373"
 "\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373"
 "\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374"
 "\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373"
 "\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373"
 "\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374"
 "\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373]"
 "\211\261\373\16\20\22\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\16\20\22\373T\201\250\373\375\375\376\373\375\375\376\373\375\375"
 "\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\375"
 "\375\376\373\375\375\376\373\375\375\376\373\375\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\373\375\375\373\\\211\260\373\15\20\22\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\15\20\22\373T\201\250\373\373"
 "\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373"
 "\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374"
 "\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373"
 "\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373"
 "\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374"
 "\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373["
 "\207\257\373\15\20\22\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\15\20\22\373T\201\250\373\375\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\375\373\374\375\375\373\374\375\375\373\374\375\375\373\374"
 "\375\375\373\374\375\375\373\374\375\375\373\374\375\375\373\374\375\375\373"
 "\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375"
 "\373\373\375\375\373\373\375\375\373Y\206\255\373\15\20\22\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\15\20\22\373T\201\250\373\373"
 "\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373"
 "\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374"
 "\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373"
 "\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373"
 "\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374"
 "\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373V"
 "\204\254\373\15\20\22\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\15\20\22\373T\201\250\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\375\373\374\375"
 "\375\373\374\375\375\373\374\375\375\373\374\375\375\373\374\375\375\373\374"
 "\375\375\373\374\375\375\373\374\375\375\373\373\375\375\373\373\375\375\373"
 "\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375"
 "\373\373\375\375\373\373\374\375\373V\202\253\373\15\20\22\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\15\20\22\373T\201\250\373\373"
 "\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373"
 "\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374"
 "\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373"
 "\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373"
 "\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374"
 "\375\373\373\374\375\373\373\374\375\373\373\374\375\373\373\374\375\373V"
 "\202\253\373\15\20\22\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10"
 "\10\10\373\15\17\22\373T\201\250\373\374\375\376\373\374\375\376\373\374\375"
 "\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374"
 "\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373"
 "\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376\373\374\375\376"
 "\373\374\375\376\373\374\375\375\373\374\375\375\373\374\375\375\373\374\375"
 "\375\373\374\375\375\373\374\375\375\373\374\375\375\373\374\375\375\373\374"
 "\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373"
 "\373\375\375\373\373\375\375\373\373\375\375\373\373\375\375\373\373\374\375"
 "\373\373\374\375\373\373\374\375\373U\201\251\373\15\20\22\373\10\10\10\373"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\15\17\22\373T\201\250\373T\201"
 "\250\373T\177\250\373T\177\250\373T\177\250\373T\177\250\373T\177\250\373"
 "T\177\250\373T\177\250\373T\201\250\373T\177\250\373T\201\250\373T\177\250"
 "\373R\177\250\373T\201\250\373R\177\250\373T\177\250\373T\201\250\373T\177"
 "\250\373R\177\250\373T\201\250\373T\177\250\373T\177\250\373T\177\250\373"
 "T\177\250\373T\201\250\373T\177\250\373T\177\250\373T\201\250\373T\177\250"
 "\373T\177\250\373T\177\250\373T\177\250\373R\177\250\373R\177\250\373T\177"
 "\250\373T\177\250\373T\177\250\373T\177\250\373T\177\250\373\15\17\22\373"
 "\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\15\17\22\373\202"
 "\247\300\373\201\244\300\373}\242\277\373\177\244\277\373\201\245\300\373"
 "\202\247\301\373\204\247\303\373\206\250\303\373Ju\236\373\212\254\305\373"
 "\214\255\306\373\216\257\307\373\217\260\307\373\221\261\310\373\222\261\311"
 "\373\224\263\311\373\225\264\313\373\227\265\314\373\230\266\315\373\233\266"
 "\315\373\235\270\316\373\236\272\317\373\237\273\320\373\237\272\320\373\237"
 "\272\320\373\237\273\320\373\237\273\320\373\237\273\320\373\237\273\320\373"
 "\237\273\320\373\237\273\320\373Ju\236\373\236\273\320\373\237\272\320\373"
 "\237\272\320\373\237\272\320\373\237\273\320\373\236\272\320\373\237\273\320"
 "\373\237\273\320\373\15\17\22\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\10\10\10\373\15\17\21\373\201\245\277\373My\241\373My\241\373Ly\241\373"
 "My\241\373My\241\373My\241\373My\241\3733V\202\373Ny\242\373Nz\242\373Ny\242"
 "\373Nz\242\373Mz\242\373Ny\242\373Nz\242\373Mz\242\373Nz\242\373Nz\242\373"
 "Nz\242\373Nz\242\373Nz\242\373P|\244\373Pz\244\373N|\244\373Pz\244\373P|\244"
 "\373Pz\244\373Pz\244\373P|\244\373P|\244\373-Nz\373Nz\244\373P|\244\373P|"
 "\244\373P|\244\373P|\244\373P|\244\373P|\244\373P|\244\373\15\17\21\373\10"
 "\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\10\10\10\373\15\17"
 "\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15"
 "\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373"
 "\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21"
 "\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17"
 "\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15"
 "\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373"
 "\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\15\17\21\373\10\10\10"
 "\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\10\10\373\10\10\10\373"
 "\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10"
 "\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10"
 "\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10"
 "\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373"
 "\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10"
 "\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10"
 "\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10\10\10\373\10"
 "\10\10\373\10\10\10\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
 "\0\0\0\0";

